import { animate, query, stagger, style, transition, trigger } from '@angular/animations';

/**
 * Defines a reusable animations object that holds the animations
 * flyInFromRight, flyInFromLeft, filterAnimation
 */
export const flyInAnimations = [
  trigger('flyInFromRight', [
    transition(':enter', [
      style({ transform: 'translateX(550px)', opacity: 1 }),
      animate(
        '0.3s 0.1s ease',
        style({
          transform: 'translateX(0)',
        })
      ),
    ]),
    transition(':leave', [
      animate(
        '0.3s ease',
        style({
          transform: 'translateX(550px)',
        })
      ),
    ]),
  ]),
  trigger('flyInFromLeft', [
    transition('0 => 1', [
      style({ transform: 'translateX(-550px)', opacity: 1 }),
      animate(
        '0.3s 0.1s ease',
        style({
          transform: 'translateX(0)',
        })
      ),
    ]),
    transition('1 => 0', [
      animate(
        '0.3s ease',
        style({
          transform: 'translateX(-550px)',
        })
      ),
    ]),
  ]),
  trigger('filterAnimation', [
    transition(':enter, * => 0, * => -1', []),
    transition(':increment', [
      query(
        ':enter',
        [
          style({ opacity: 0, width: '0px' }),
          stagger(55, [animate('300ms ease-out', style({ opacity: 1, width: '*' }))]),
        ],
        { optional: true }
      ),
    ]),
    transition(':decrement', [
      query(':leave', [
        stagger(5, [animate('300ms ease-out', style({ opacity: 0, width: '0px' }))]),
      ]),
    ]),
  ]),
];
