import { OverlayModule } from '@angular/cdk/overlay';
import { HttpClientModule } from '@angular/common/http';
import { Injector, NgModule } from '@angular/core';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { MatAutocompleteModule } from '@angular/material/autocomplete';
import { MatButtonModule } from '@angular/material/button';
import { MatButtonToggleModule } from '@angular/material/button-toggle';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatChipsModule } from '@angular/material/chips';
import { MatNativeDateModule } from '@angular/material/core';
import { MatDatepickerModule } from '@angular/material/datepicker';
import { MatDialogModule } from '@angular/material/dialog';
import { MatExpansionModule } from '@angular/material/expansion';
import { MatIconModule } from '@angular/material/icon';
import { MatInputModule } from '@angular/material/input';
import { MatListModule } from '@angular/material/list';
import { MatPaginatorModule } from '@angular/material/paginator';
import { MatSelectModule } from '@angular/material/select';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { MatSortModule } from '@angular/material/sort';
import { MatTableModule } from '@angular/material/table';
import { MatTabsModule } from '@angular/material/tabs';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatTreeModule } from '@angular/material/tree';
import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { BsModalService } from 'ngx-bootstrap/modal';
import { NgxMatSelectSearchModule } from 'ngx-mat-select-search';
import { StaticInjectorService } from './abstract-page/static-injector';
import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';
import { DaterangeToggleGroupComponent } from './components/daterange-toggle-group/daterange-toggle-group.component';
import { ExpandToOverlayButtonComponent } from './components/expand-to-overlay-button/expand-to-overlay-button.component';
import { InfoBoxComponent } from './components/info-box/info-box.component';
import { LoadingSpinnerComponent } from './components/loading-spinner/loading-spinner.component';
import { MarkerComponent } from './components/marker/marker.component';
import { PopoverSettingsComponent } from './components/popover-settings/popover-settings.component';
import { TimespanSelectorComponent } from './components/timespan-selector/timespan-selector.component';
import { TopicSelectionBarComponent } from './components/topic-selection-bar/topic-selection-bar.component';
import { TopicToggleGroupComponent } from './components/topic-toggle-group/topic-toggle-group.component';
import { DashboardElementsOverlayComponent } from './dashboard-elements-overlay/dashboard-elements-overlay.modal';
import { ArticleCountComponent } from './dashboard-elements/article-count/article-count.component';
import { ArticleTopicCircleComponent } from './dashboard-elements/article-topic-circle/article-topic-circle.component';
import { HotMediaComponent } from './dashboard-elements/hot-media/hot-media.component';
import { HotTopicsComponent } from './dashboard-elements/hot-topics/hot-topics.component';
import { MensaComponent } from './dashboard-elements/mensa/mensa.component';
import { MessagesComponent } from './dashboard-elements/messages/messages.component';
import { RegionalInfluenceComponent } from './dashboard-elements/regional-influence/regional-influence.component';
import { SunburstComponent } from './dashboard-elements/sunburst/sunburst.component';
import {
  TdtFormComponent,
  TdtFormConfComponent,
  TdtFormDialogComponent,
  TdtFormSendComponent,
} from './dashboard-elements/tdt/tdt-form/tdt-form.component';
import { TdTComponent } from './dashboard-elements/tdt/tdt.component';
import { TopicPopularityComponent } from './dashboard-elements/topic-popularity/topic-popularity.component';
import { TopicReachComponent } from './dashboard-elements/topic-reach/topic-reach.component';
import { DashboardComponent } from './dashboard/dashboard.component';
import { DashboardElementDirective } from './directives/dashboard-element.directive';
import { PopoverComponent } from './directives/popover/popover.component';
import { PopoverDirective } from './directives/popover/popover.directive';
import { PopoverService } from './directives/popover/popover.service';
import { httpInterceptorProviders } from './interceptors';

@NgModule({
  declarations: [
    AppComponent,
    MessagesComponent,
    TdTComponent,
    MensaComponent,
    ArticleTopicCircleComponent,
    TdtFormComponent,
    TdtFormDialogComponent,
    TdtFormConfComponent,
    TdtFormSendComponent,
    DashboardComponent,
    DashboardElementDirective,
    MarkerComponent,
    TopicPopularityComponent,
    HotTopicsComponent,
    SunburstComponent,
    HotMediaComponent,
    InfoBoxComponent,
    RegionalInfluenceComponent,
    ArticleCountComponent,
    TopicReachComponent,
    DashboardElementsOverlayComponent,
    LoadingSpinnerComponent,
    TopicSelectionBarComponent,
    TopicToggleGroupComponent,
    DaterangeToggleGroupComponent,
    ExpandToOverlayButtonComponent,
    TimespanSelectorComponent,
    PopoverComponent,
    PopoverDirective,
    PopoverSettingsComponent,
  ],
  imports: [
    BrowserModule,
    MatCheckboxModule,
    HttpClientModule,
    BrowserAnimationsModule,
    MatSelectModule,
    FormsModule,
    MatInputModule,
    ReactiveFormsModule,
    AppRoutingModule,
    MatTabsModule,
    MatButtonToggleModule,
    MatIconModule,
    MatButtonModule,
    MatDatepickerModule,
    MatNativeDateModule,
    MatListModule,
    MatSlideToggleModule,
    MatTableModule,
    MatChipsModule,
    MatDialogModule,
    MatAutocompleteModule,
    MatSortModule,
    MatExpansionModule,
    NgxMatSelectSearchModule,
    OverlayModule,
    MatTreeModule,
    MatPaginatorModule,
    MatTooltipModule,
  ],
  providers: [httpInterceptorProviders, BsModalService, PopoverService],
  exports: [InfoBoxComponent],
  bootstrap: [AppComponent],
})
export class AppModule {
  constructor(injector: Injector) {
    StaticInjectorService.setInjector(injector);
  }
}
