import { Component, EventEmitter, Input, Output } from '@angular/core';
import { MatButtonToggleChange } from '@angular/material/button-toggle';

/**
 *  defines the components selector and the components corresponding html and css file(s)
 */
@Component({
  selector: 'app-daterange-toggle-group',
  templateUrl: './daterange-toggle-group.component.html',
  styleUrls: ['./daterange-toggle-group.component.css'],
})
export class DaterangeToggleGroupComponent {
  /** value that represents the active tab
   *    '0': show most popular media among all available topics
   *    '1': show most popular media among user selected topics (default)
   *    '2': show most popular media only for highlighted topic
   */
  @Input() activeTab: string;

  /**
   *  whether the setting should be disabled for a component
   */
  @Input() disabled = false;

  /**
   *  emits an event to the parent component when the selection has changed
   */
  @Output() selectionChanged = new EventEmitter<string>();

  /**
   * inject the necessary services that are used in this component
   */
  constructor() {}

  /**
   *  updates the active tab and emits the selectionChanged event
   */
  changeSelection(event: MatButtonToggleChange) {
    this.activeTab = event.value;
    this.selectionChanged.emit(this.activeTab);
  }
}
