import { Component, EventEmitter, Input, Output } from '@angular/core';
import { TimespanType } from '../../services/one-up-api.service';

/**
 * defines the components selector and the components corresponding html and css file(s)
 */
@Component({
  selector: 'app-popover-settings',
  templateUrl: './popover-settings.component.html',
  styleUrls: ['./popover-settings.component.css'],
})
export class PopoverSettingsComponent {
  /** value that represents the active tab
   *    '0': show most popular media among all available topics
   *    '1': show most popular media among user selected topics (default)
   *    '2': show most popular media only for highlighted topic
   */
  @Input() topicActiveTab: string;

  /** value that represents the active tab
   *    '0': number of weekly changes in articles reporting on the selected topics (default)
   *    '1': number of monthly changes in articles reporting on the selected topics
   */
  @Input() daterangeActiveTab: string;

  /**
   *  holds the name of the highlighted topic
   */
  @Input() highlightedTopic: string;

  /**
   *  indicates which settings are enabled for this component
   */
  @Input() activeSettings: boolean[];

  /**
   *  holds the state of app-timespan-selector
   */
  @Input() selectedTimespan: TimespanType;

  /**
   *  emits an event to the parent component when the timespan selection has changed
   */
  @Output() timespanSelectionChanged = new EventEmitter<string>();

  /**
   *  emits an event to the parent component when the date range selection has changed
   */
  @Output() daterangeSelectionChanged = new EventEmitter<string>();

  /**
   *  emits an event to the parent component when the topic range selection has changed
   */
  @Output() topicSelectionChanged = new EventEmitter<string>();
}
