import { Injectable } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';

/**
 * Defines the popover service as an injectable class.
 */
@Injectable()
export class PopoverService {
  /**
   * The state of the popover.
   */
  private state: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);

  /**
   * Returns the state of the popover.
   *
   * @returns State as Observable<boolean> which indicates the state of the popover.
   */
  getState(): Observable<boolean> {
    return this.state.asObservable();
  }

  /**
   *  Sets the state of the popover.
   *
   * @param value boolean which indicates the new state of the popover.
   */
  setState(value: boolean) {
    return this.state.next(value);
  }
}
