/**
 * Representation of an allergen.
 */
export interface Allergen {
  /**
   * The type of the allergen.
   */
  type: string;

  /**
   * The short name of the allergen.
   */
  shortName: string;

  /**
   * The long name of the allergen.
   */
  longName: string;

  /**
   * The description of the allergen.
   */
  description: string;

  /**
   * The description type of the allergen.
   */
  descriptionType: string;
}

/**
 * Representation of an icon
 */
export interface IconEntry {
  /**
   * Name of the icon
   */
  key: string;

  /**
   * Where to find the icon
   */
  value: string;
}

/**
 * Map of icons
 */
export interface IconMap {
  /**
   * Holds a key/value pair of icon entries
   */
  entry: IconEntry[];
}

/**
 * A representation of a meal.
 */
export interface Meal {
  /**
   * Date where this meal is served.
   */
  date: string;

  /**
   * Price structure of this meal.
   */
  prices: Prices;

  /**
   * Name of the meal.
   */
  title: string;

  /**
   * Type of the meal.
   */
  type: string[];

  /**
   * Description of the meal.
   */
  description: string;

  /**
   * Allergens of the meal.
   */
  allergens: Allergen[];

  /**
   * Number of the meal to sort and display in correct order.
   */
  order: number;
}

/**
 * Meals object for a campus
 */
export interface Meals {
  /**
   * The name of the campus
   */
  campus: string;

  /**
   * Icons for certain ingredients, allergens, vegan, etc.
   */
  iconHashMap: IconMap;

  /**
   * Array of meals for the campus
   */
  meal: Meal[];
}

/**
 * Price structure for different groups of people
 */
export interface Prices {
  /**
   * Price for students
   */
  student: number;

  /**
   * Price for employees
   */
  staff: number;

  /**
   * Price for guests / everyone else
   */
  guest: number;
}
