/* eslint-disable @typescript-eslint/naming-convention */

/**
 *  Describes, how the getHotTopics() API response looks like
 */
export interface HotTopic {
  /**
   *  name of the topic
   */
  tag_name: string;

  /**
   *  total amount of articles about the topic
   */
  article_count: number;

  /**
   *  article_count divided by total amount of articles in the database (for all topics)
   */
  hotness_factor: number;

  /**
   *  difference in amount of publications in comparison to last week
   */
  diff_last_week: number;

  /**
   *  difference in amount of publications in comparison to last month
   */
  diff_last_month: number;
}

/**
 *  Describes, how the getUserTagsWithArticleCount() API response looks like
 */
export interface MediaOverview {
  /**
   *  name of the topic
   */
  tag_name: string;

  /**
   *  total amount of articles about the topic
   */
  count: number;

  /**
   *  amount of articles about the topic in regional media
   */
  regional_count: number;

  /**
   *  amount of articles about the topic in national media
   */
  national_count: number;

  /**
   *  amount of articles about the topic in online media
   */
  web_count: number;
}

/**
 *  Describes, how the getTagsTimeview() API response looks like
 */
export interface ReachOfTopic {
  /**
   *  name of the topic
   */
  name: string;

  /**
   *  month that the data relates to
   */
  month: number;

  /**
   *  month that the data relates to
   */
  year: number;

  /**
   *  potential amount of readers that could've been reached
   */
  reach: number;

  /**
   *  articles that have been published in that month about that topic
   */
  article_count: number;
}

/**
 *  Describes, how the getTagsOverview() API response looks like
 */
export interface TagsOverview {
  /**
   *  name of the category
   */
  name: string;

  /**
   *  holds all topics that belong to that category
   */
  tags: UserTopic[];
}

/**
 *  Describes, how a tag in getTagsOverview() looks like
 */
export interface UserTopic {
  /**
   *  name of the topic
   */
  name: string;
}

/**
 *  Describes, how the getHotMedia() API response looks like
 */
export interface TopMedium {
  /**
   *  name of the medium
   */
  medium_name: string;

  /**
   *  how many articles have been published in this medium
   *  that fit the selected topics
   */
  article_count: number;
}

/**
 *  Describes, how the getTopics() API response looks like
 */
export interface TopicWithArticle {
  /**
   *  name of the article's topic
   */
  name: string;

  /**
   *  name of the article
   */
  article_name: string;

  /**
   *  name of the article's medium
   */
  medium_name: string;

  /**
   *  when the article was published
   */
  date_of_publication: string;

  /**
   *  how many readers the article could have possibly reached
   */
  reach: bigint;
}
