import { Injectable } from '@angular/core';
import * as d3 from 'd3';

/**
 *  service which defines the d3.js tooltips that are shown on mouseover/hover
 */
@Injectable({
  providedIn: 'root',
})
export class HoverTooltipService {
  /**
   *  Creates the tooltip, which is hidden by default
   */
  createTooltip() {
    const tooltip = d3
      .select('body')
      .append('div')
      .attr('id', 'hoverTooltip')
      .style('position', 'absolute')
      .style('z-index', '1000')
      .style('display', 'none')
      .style('background', '#fff')
      .style('background-color', 'white')
      .style('border', 'solid')
      .style('border-width', '1px')
      .style('border-radius', '2px')
      .style('padding', '5px')
      .text('a simple tooltip')
      .on('click', () => tooltip.style('display', 'none'));

    return tooltip;
  }

  /**
   *  When the user hovers over the an element, show the tooltip
   *  and also increase the targets opacity (feels more interactive)
   */
  mouseover(event, d, tooltip) {
    d3.selectAll('#hoverTooltip').style('display', 'none');
    tooltip.style('display', 'block');
    d3.select(event.target).style(
      'opacity',
      Number(d3.select(event.target).style('opacity')) + 0.35
    );
  }

  /**
   *  For every movement, update the tooltips text and it's position
   *  based on the cursor position
   */
  mousemove(event, d, tooltip, tooltipHtml) {
    tooltip
      .html(tooltipHtml)
      .style('left', event.pageX + 10 + 'px')
      .style('top', event.pageY - 60 + 'px');
  }

  /**
   *  Hide the tooltip once the mouse leaves the target
   *  and restore targets default opacity
   */
  mouseleave(event, d, tooltip) {
    tooltip.style('display', 'none');
    if (Number(d3.select(event.target).style('opacity')) > 0.65) {
      d3.select(event.target).style(
        'opacity',
        Number(d3.select(event.target).style('opacity')) - 0.35
      );
    }
  }
}
