import { HttpRequest } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { MessageService } from './message.service';

/**
 * Cache Wrapper class. It is just a map with some functional classes to use the private map outside.
 */
@Injectable({
  providedIn: 'root',
})
export class HttpRequestCache {
  /**
   * Map which is used for caching
   *
   * @private
   */
  private cache: Map<string, any>;

  /**
   * Constructs the cache
   *
   * @param messageService
   */
  constructor(private messageService: MessageService) {
    this.cache = new Map<any, any>();
  }

  /**
   * Inserts a request with its response to the cache.
   *
   * @param req HttpRequest
   * @param resp HttpResponse
   */
  put(req: HttpRequest<any>, resp: any) {
    this.cache.set(req.urlWithParams, resp);
  }

  /**
   * Use the cache for a specific HttpRequest
   *
   * @param req HttpRequest
   */
  get(req: HttpRequest<any>) {
    if (this.cache.has(req.urlWithParams)) {
      this.messageService.add('RequestGetCache: found cache');
      return this.cache.get(req.urlWithParams);
    }
    this.messageService.add('RequestGetCache: found nothing');
    return null;
  }

  /**
   * Clears the cache.
   */
  clear() {
    this.cache.clear();
  }
}
