import { DOCUMENT } from '@angular/common';
import { Inject, Injectable } from '@angular/core';
import { animationFrameScheduler, fromEvent, merge, Observable, of } from 'rxjs';
import {
  auditTime,
  delay,
  distinctUntilChanged,
  map,
  share,
  startWith,
  switchMap
} from 'rxjs/operators';

@Injectable({
  providedIn: 'root',
})
export class IdleService {
  private readonly userActivity$: Observable<void>;

  constructor(@Inject(DOCUMENT) private readonly document: Document) {
    this.userActivity$ = merge
      .apply(
        null,
        IdleService.userActivityEvents.map(
          (event: string): Observable<Event> => fromEvent(this.document, event)
        )
      )
      .pipe(
        auditTime(0, animationFrameScheduler),
        map((): void => void 0),
        share()
      );
  }

  private static get userActivityEvents(): ReadonlyArray<string> {
    // defines which activities are tracked to determine if a user is idle
    return [
      'keypress',
      'keydown',
      'click',
      'contextmenu',
      'mousemove',
      'scroll',
      'touchmove',
      'touchstart',
    ];
  }

  public getIdleStream(delayDuration: number = 5000): Observable<boolean> {
    const userActivity$: Observable<boolean> = this.userActivity$.pipe(
      startWith(null),
      map(() => false)
    );

    const idle$: Observable<boolean> = userActivity$.pipe(
      switchMap(() => of(true).pipe(delay(delayDuration)))
    );

    return merge(userActivity$, idle$).pipe(distinctUntilChanged());
  }
}
