import { Injectable } from '@angular/core';
import * as d3 from 'd3';
import { MiSeService } from './mise.service';

@Injectable({
  providedIn: 'root',
})
export class SunburstService {
  g: any;
  path: any;
  width = 250;
  height = 250;
  radius = Math.min(this.width, this.height) / 2;
  color = d3.scaleOrdinal(d3.schemeSet3);
  partition: any;
  nodeData: any;
  root: any;
  arc: any;
  sunburst: any;
  svg: any;
  sunburstdata: any;

  getData() {
    this.sunburstdata = JSON.parse(MiSeService.sunburstData);
  }

  createSVGSun() {
    this.sunburstdata = JSON.parse(MiSeService.sunburstData);
    this.svg = d3
      .select('#sunburst')
      .append('svg')
      .attr('width', this.width)
      .attr('height', this.height)
      .attr('class', 'svg');
    this.g = d3
      .select('.svg')
      .append('g')
      .attr('transform', 'translate(' + this.width / 2 + ',' + this.height / 2 + ')');

    this.partition = d3.partition().size([2 * Math.PI, this.radius]);

    // Find the root node of our data, and begin sizing process.
    this.root = d3.hierarchy(this.sunburstdata).sum((d) => d.size);

    // Calculate the sizes of each arc that we'll draw later.
    this.partition(this.root);
    this.arc = d3
      .arc()
      .startAngle((d) => d.x0)
      .endAngle((d) => d.x1)
      .innerRadius((d) => d.y0)
      .outerRadius((d) => d.y1);
    // Add a <g> element for each node in the data, then append <path> elements and draw lines based on the arc
    // variable calculations. Last, color the lines and the slices.
    this.path = this.g
      .selectAll('path')
      .data(this.root.descendants())
      .enter()
      .append('path')
      .attr('class', 'node')
      .attr('display', (d) => (d.depth ? null : 'none'))
      .attr('d', this.arc)
      .style('stroke', '#fff')
      .style('fill', (d) => this.color((d.children ? d : d.parent).data.name));
  }
}

/*createZoomableSunburst() {
      const width = 500;
      const height = 500;
      const radius = Math.min(width, height) / 2;
      const color = d3.scaleOrdinal(d3.schemeSet3);

      // Size our <svg> element, add a <g> element, and move translate 0,0 to the center of the element.
      const g = d3.selectAll('svg')
        .attr('width', width)
        .attr('height', height)
        .append('g')
        .attr('transform', 'translate(' + width / 2 + ',' + height / 2 + ')');

    // Create our sunburst data structure and size it.
    const partition = d3.partition()
      .size([2 * Math.PI, radius]);

    // Get the data from our JSON file
    d3.json('data.json', (error, nodeData) => {
      if (error) throw error;

      // Find the root node of our data, and begin sizing process.
      const root = d3.hierarchy(nodeData)
        .sum( (d) => { return d.size});

      // Calculate the sizes of each arc that we'll draw later.
      partition(root);
      const arc = d3.arc()
        .startAngle( (d) => { return d.x0 })
        .endAngle( (d) => { return d.x1 })
        .innerRadius( (d) => { return d.y0 })
        .outerRadius( (d) =>{ return d.y1 });


      // Add a <g> element for each node in thd data, then append <path> elements and draw lines based on the arc
      // variable calculations. Last, color the lines and the slices.
      g.selectAll('g')
        .data(root.descendants())
        .enter().append('g').attr('class', 'node').append('path')
        .attr('display',  (d) => { return d.depth ? null : 'none'; })
        .attr('d', arc)
        .style('stroke', '#fff')
        .style('fill',  (d) => { return color((d.children ? d : d.parent).data.name); });


      // Populate the <text> elements with our data-driven titles.
        g.selectAll('.node')
          .append('text')
          .attr('transform', (d) => {
            return 'translate(' + arc.centroid(d) + ')rotate(' + computeTextRotation(d) + ')'; })
          .attr('dx', '-20') // radius margin
          .attr('dy', '.5em') // rotation align
          .text((d) => { return d.parent ? d.data.name : '' });

      });

      function computeTextRotation(d) {
        const angle = (d.x0 + d.x1) / Math.PI * 90;

        // Avoid upside-down labels
        return (angle < 120 || angle > 270) ? angle : angle + 180;  // labels as rims
        // return (angle < 180) ? angle - 90 : angle + 90;  // labels as spokes
      }
    }*/
