import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable, of } from 'rxjs';
import { catchError, map, tap } from 'rxjs/operators';
import { Tdt } from '../interfaces/tdt';
import { MessageService } from './message.service';

@Injectable({
  providedIn: 'root',
})
export class TdTService {
  private url = 'http://localhost:8081/tdt/api';
  private standardTdT =
    'Manchmal stärken auch Kleinigkeiten die Transferkompetenz. \r\n' +
    'Zum Beispiel zählen Abschlussarbeiten mit regionalen Unternehmen schon als Transfer.';

  constructor(private messageService: MessageService, private http: HttpClient) {}

  getTdt(): Observable<Tdt> {
    return this.http.get<Tdt>(this.url, { observe: 'response' }).pipe(
      tap((_) => this.log('fetched TdT')),
      map((response) => response.body),
      catchError(this.handleError<Tdt>('getTdt', { text: this.standardTdT }))
    );
  }

  private log(message: string) {
    this.messageService.add(`TdTService: ${message}`);
  }

  private handleError<T>(operation = 'operation', result?: T) {
    return (error: any): Observable<T> => {
      // TODO: send the error to remote logging infrastructure
      console.error(error); // log to console instead

      // TODO: better job of transforming error for user consumption
      this.messageService.log('TodoService', `${operation} failed: ${error.message}`);

      // Let the app keep running by returning an empty result.
      return of(result as T);
    };
  }
}
