import { Injectable } from '@angular/core';
import { AllFeedback } from '../mise-va/entities/AllFeedback';
import { Indicator } from '../mise-va/entities/Indicator';
import { VAFeedback } from '../mise-va/entities/VAFeedback';
import { VAResponse } from '../mise-va/entities/VAResponse';
import { MiSeService } from './mise.service';
import { VaResponseService } from './va-response.service';

@Injectable({
  providedIn: 'root',
})
export class VeranstaltungService {
  private feedback: VAResponse;
  private filter = [];
  private vaResponseService: VaResponseService = new VaResponseService();

  getFeeback(): VAResponse {
    this.updateFeedback();
    return this.feedback;
  }

  updateFeedback() {
    this.feedback = JSON.parse(MiSeService.miSeVaResponse) as VAResponse;
    this.vaResponseService.addVAResult(this.feedback);
  }

  getIndicators(): Indicator[] {
    if (this.feedback == null) {
      this.updateFeedback();
    }
    return this.vaResponseService.getIndicators();
  }

  getIndicatorIds(): string[] {
    return this.getIndicators()
      .filter((ind) => this.filter.indexOf(ind.id) < 0)
      .map((ind) => ind.id);
  }

  getStackedData(): AllFeedback {
    if (this.feedback == null) {
      this.updateFeedback();
    }
    const stackedData = new AllFeedback();

    const feedback = this.feedback;
    feedback.events.forEach((event) => {
      const vaFeedback = new VAFeedback(event.eventName);
      vaFeedback.createPropActual();
      feedback.indicators.forEach((indicator) => {
        const questionAnswer = event.questionAnswers.find((qa) => qa.indicator === indicator.id);
        if (questionAnswer === undefined) {
          vaFeedback.prop[indicator.id] = 0;
          vaFeedback.actual[indicator.id] = 0;
        } else {
          vaFeedback.prop[indicator.id] = questionAnswer.proposed;
          vaFeedback.actual[indicator.id] = questionAnswer.actual;
        }
      });

      stackedData.addFeedback(vaFeedback);
    });
    return stackedData;
  }

  addFilter(element: string) {
    this.filter.push(element);
  }

  removeFilter(element: string) {
    const index = this.filter.indexOf(element, 0);
    if (index > -1) {
      this.filter.splice(index, 1);
    }
  }

  clearFilter() {
    this.filter = [];
  }
}
