import { Injectable } from '@angular/core';
import * as d3 from 'd3';
import { ColorService } from './color.service';

@Injectable({
  providedIn: 'root',
})
export class AreaChartService {
  constructor(private colorService: ColorService) {}

  createSVG(element, options) {
    return d3
      .select(element)
      .append('svg')
      .attr('width', options.width + options.margin.left + options.margin.right)
      .attr('height', options.height + options.margin.top + options.margin.bottom)
      .append('g')
      .attr('transform', 'translate(' + options.margin.left + ',' + options.margin.top + ')');
  }

  updateArea(options, data) {
    const t = options.element.transition().duration(750);
    const series = d3.stack().keys(options.categories)(data);
    const x = d3
      .scaleUtc()
      .domain(d3.extent(data, (d) => d.date))
      .range([options.margin.left, options.width - options.margin.right]);
    const y = d3
      .scaleLinear()
      .domain([0, d3.max(series, (d) => d3.max(d, (d) => d[1]))])
      .nice()
      .range([options.height - options.margin.bottom, options.margin.top]);

    const xAxis = (g) =>
      g.attr('transform', `translate(0,${options.height - options.margin.bottom})`).call(
        d3
          .axisBottom(x)
          .ticks(options.width / 80)
          .tickSizeOuter(0)
      );
    const yAxis = (g) =>
      g
        .attr('transform', `translate(${options.margin.left}, 0)`)
        .call(d3.axisLeft(y).tickFormat((d) => d3.format('.2s')(d)))
        .call((g) => g.select('.domain').remove())
        .call((g) =>
          g
            .select('.tick:last-of-type text')
            .clone()
            .attr('x', 3)
            .attr('text-anchor', 'start')
            .attr('font-weight', 'bold')
            .text(options.categories[0])
        );
    const area = d3
      .area()
      .x((d) => x(d.data.date))
      .y0((d) => y(d[0]))
      .y1((d) => y(d[1]));

    options.element
      .selectAll('path')
      .data(series)
      .join(
        (enter) =>
          enter
            .append('path')
            .attr('fill', options.scheme(options.topic))
            .attr('d', area)
            .append('title')
            .text(({ key }) => key)
            .call((enter) => enter.transition(t)),
        (update) =>
          update
            .attr('fill', this.colorService.loading.primary)
            .call((update) =>
              update.transition(t).attr('fill', options.scheme(options.topic)).attr('d', area)
            ),
        (exit) => exit.call((exit) => exit.transition(t).remove())
      );

    options.element.select('#xAxis').remove();
    options.element.select('#yAxis').remove();
    options.element.append('g').attr('id', 'xAxis').call(xAxis);

    options.element.append('g').attr('id', 'yAxis').call(yAxis);
  }
}
